# FetoFlow

This is a Python Library developed by Jordan Blennerhassett and Jude Beullens under the guidance of Alys Clark and Sahan Jayatissa for use in computational modelling of fetoplacental vascular networks.

**Documentation:** https://virtualpregnancy.github.io/fetoflow/
